/* This file is part of Om.  Copyright (C) 2005 Dave Robillard.
 * 
 * Om is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Om is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef DSSIMODULE_H
#define DSSIMODULE_H

#include "OmModule.h"

namespace OmGtk {
	
	
class DSSIModule : public OmModule
{
public:
	DSSIModule(OmPatchBayArea* patch_bay, NodeModel* nm, PatchController* patch_controller);
	virtual ~DSSIModule() {}

	void on_double_click();
	bool attempt_to_show_gui();
	void show_gui();
};


} // namespace OmGtk

#endif // DSSIMODULE_H
